==> ejc-salary-api-3.0.0-20250820.033912-167-sources.jar: com/ejianc/business/salary/vo/PushcwVO.java <==
package com.ejianc.business.salary.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 实发明细
 * 
 * @author generator
 * 
 */
public class PushcwVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long jspayableDetailId; // 所属明细id
    private Long detailEmployeeId; // 员工主键
    private String detailEmployeeName; // 员工名称
    private String detailEmployeeCode; // 员工编码
    private Date month; // 月份
    private String idCard; // 证件号码
    private Long orgId; // 单位id
    private String orgName; // 单位名称
    private String orgCode; // 单位编码
    private Long sourceId; // 应发上传id
    private Long sourceDetailId; // 应发上传明细id
    private Date period; // 应发工资计算的 月份
    private Long companyId; // 所属公司id
    private String companyName; // 所属公司名称
    private BigDecimal yingfa; // 
    private BigDecimal dabingyibao; // 
    private BigDecimal gerenyanglao; // 
    private BigDecimal gerenyibao; // 
    private BigDecimal gerenshiye; // 
    private BigDecimal gerengongjijin; // 
    private BigDecimal geshui; // 
    private BigDecimal yingfamianshui; // 
    private BigDecimal yingfamianshuicw; // 
    private BigDecimal actual; // 
    private String bankName; // 开户行
    private String bankAccount; // 银行账户
    private String bankAddress; // 银行地址
    private String acSetCode; // 账套编码
    private String acSet; // 账套名称
    private BigDecimal alreadyMny; //
    private String code; // 编号


    public BigDecimal getAlreadyMny() {
        return alreadyMny;
    }

    public void setAlreadyMny(BigDecimal alreadyMny) {
        this.alreadyMny = alreadyMny;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public Long getJspayableDetailId() {
        return jspayableDetailId;
    }

    public void setJspayableDetailId(Long jspayableDetailId) {
        this.jspayableDetailId = jspayableDetailId;
    }
    public Long getDetailEmployeeId() {
        return detailEmployeeId;
    }

    public void setDetailEmployeeId(Long detailEmployeeId) {
        this.detailEmployeeId = detailEmployeeId;
    }
    public String getDetailEmployeeName() {
        return detailEmployeeName;
    }

    public void setDetailEmployeeName(String detailEmployeeName) {
        this.detailEmployeeName = detailEmployeeName;
    }
    public String getDetailEmployeeCode() {
        return detailEmployeeCode;
    }

    public void setDetailEmployeeCode(String detailEmployeeCode) {
        this.detailEmployeeCode = detailEmployeeCode;
    }
    public Date getMonth() {
        return month;
    }

    public void setMonth(Date month) {
        this.month = month;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public Date getPeriod() {
        return period;
    }

    public void setPeriod(Date period) {
        this.period = period;
    }
    public Long getCompanyId() {
        return companyId;
    }

    public void setCompanyId(Long companyId) {
        this.companyId = companyId;
    }
    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }
    public BigDecimal getYingfa() {
        return yingfa;
    }

    public void setYingfa(BigDecimal yingfa) {
        this.yingfa = yingfa;
    }
    public BigDecimal getDabingyibao() {
        return dabingyibao;
    }

    public void setDabingyibao(BigDecimal dabingyibao) {
        this.dabingyibao = dabingyibao;
    }
    public BigDecimal getGerenyanglao() {
        return gerenyanglao;
    }

    public void setGerenyanglao(BigDecimal gerenyanglao) {
        this.gerenyanglao = gerenyanglao;
    }
    public BigDecimal getGerenyibao() {
        return gerenyibao;
    }

    public void setGerenyibao(BigDecimal gerenyibao) {
        this.gerenyibao = gerenyibao;
    }
    public BigDecimal getGerenshiye() {
        return gerenshiye;
    }

    public void setGerenshiye(BigDecimal gerenshiye) {
        this.gerenshiye = gerenshiye;
    }
    public BigDecimal getGerengongjijin() {
        return gerengongjijin;
    }

    public void setGerengongjijin(BigDecimal gerengongjijin) {
        this.gerengongjijin = gerengongjijin;
    }
    public BigDecimal getGeshui() {
        return geshui;
    }

    public void setGeshui(BigDecimal geshui) {
        this.geshui = geshui;
    }
    public BigDecimal getYingfamianshui() {
        return yingfamianshui;
    }

    public void setYingfamianshui(BigDecimal yingfamianshui) {
        this.yingfamianshui = yingfamianshui;
    }
    public BigDecimal getYingfamianshuicw() {
        return yingfamianshuicw;
    }

    public void setYingfamianshuicw(BigDecimal yingfamianshuicw) {
        this.yingfamianshuicw = yingfamianshuicw;
    }
    public BigDecimal getActual() {
        return actual;
    }

    public void setActual(BigDecimal actual) {
        this.actual = actual;
    }
    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    public String getBankAccount() {
        return bankAccount;
    }

    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }
    public String getBankAddress() {
        return bankAddress;
    }

    public void setBankAddress(String bankAddress) {
        this.bankAddress = bankAddress;
    }
    public String getAcSetCode() {
        return acSetCode;
    }

    public void setAcSetCode(String acSetCode) {
        this.acSetCode = acSetCode;
    }
    public String getAcSet() {
        return acSet;
    }

    public void setAcSet(String acSet) {
        this.acSet = acSet;
    }
    
}

==> ejc-salary-api-3.0.0-20250903.000326-181-sources.jar: com/ejianc/business/salary/vo/PushcwVO.java <==
package com.ejianc.business.salary.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 实发明细
 * 
 * @author generator
 * 
 */
public class PushcwVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long jspayableDetailId; // 所属明细id
    private Long detailEmployeeId; // 员工主键
    private String detailEmployeeName; // 员工名称
    private String detailEmployeeCode; // 员工编码
    private Date month; // 月份
    private String idCard; // 证件号码
    private Long orgId; // 单位id
    private String orgName; // 单位名称
    private String orgCode; // 单位编码
    private Long sourceId; // 应发上传id
    private Long sourceDetailId; // 应发上传明细id
    private Date period; // 应发工资计算的 月份
    private Long companyId; // 所属公司id
    private String companyName; // 所属公司名称
    private BigDecimal yingfa; // 
    private BigDecimal dabingyibao; // 
    private BigDecimal gerenyanglao; // 
    private BigDecimal gerenyibao; // 
    private BigDecimal gerenshiye; // 
    private BigDecimal gerengongjijin; // 
    private BigDecimal geshui; // 
    private BigDecimal yingfamianshui; // 
    private BigDecimal yingfamianshuicw; // 
    private BigDecimal actual; // 
    private String bankName; // 开户行
    private String bankAccount; // 银行账户
    private String bankAddress; // 银行地址
    private String acSetCode; // 账套编码
    private String acSet; // 账套名称
    private BigDecimal alreadyMny; //
    private String code; // 编号
    private Date stateUpdateTime;
    private String sourceType; // 来源（工资单，重发单）
    private String payState; // 0-待支付、1-银行支付中、2-支付成功、3-支付失败

    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }

    public String getPayState() {
        return payState;
    }

    public void setPayState(String payState) {
        this.payState = payState;
    }

    public Date getStateUpdateTime() {
        return stateUpdateTime;
    }

    public void setStateUpdateTime(Date stateUpdateTime) {
        this.stateUpdateTime = stateUpdateTime;
    }

    public BigDecimal getAlreadyMny() {
        return alreadyMny;
    }

    public void setAlreadyMny(BigDecimal alreadyMny) {
        this.alreadyMny = alreadyMny;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public Long getJspayableDetailId() {
        return jspayableDetailId;
    }

    public void setJspayableDetailId(Long jspayableDetailId) {
        this.jspayableDetailId = jspayableDetailId;
    }
    public Long getDetailEmployeeId() {
        return detailEmployeeId;
    }

    public void setDetailEmployeeId(Long detailEmployeeId) {
        this.detailEmployeeId = detailEmployeeId;
    }
    public String getDetailEmployeeName() {
        return detailEmployeeName;
    }

    public void setDetailEmployeeName(String detailEmployeeName) {
        this.detailEmployeeName = detailEmployeeName;
    }
    public String getDetailEmployeeCode() {
        return detailEmployeeCode;
    }

    public void setDetailEmployeeCode(String detailEmployeeCode) {
        this.detailEmployeeCode = detailEmployeeCode;
    }
    public Date getMonth() {
        return month;
    }

    public void setMonth(Date month) {
        this.month = month;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public Date getPeriod() {
        return period;
    }

    public void setPeriod(Date period) {
        this.period = period;
    }
    public Long getCompanyId() {
        return companyId;
    }

    public void setCompanyId(Long companyId) {
        this.companyId = companyId;
    }
    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }
    public BigDecimal getYingfa() {
        return yingfa;
    }

    public void setYingfa(BigDecimal yingfa) {
        this.yingfa = yingfa;
    }
    public BigDecimal getDabingyibao() {
        return dabingyibao;
    }

    public void setDabingyibao(BigDecimal dabingyibao) {
        this.dabingyibao = dabingyibao;
    }
    public BigDecimal getGerenyanglao() {
        return gerenyanglao;
    }

    public void setGerenyanglao(BigDecimal gerenyanglao) {
        this.gerenyanglao = gerenyanglao;
    }
    public BigDecimal getGerenyibao() {
        return gerenyibao;
    }

    public void setGerenyibao(BigDecimal gerenyibao) {
        this.gerenyibao = gerenyibao;
    }
    public BigDecimal getGerenshiye() {
        return gerenshiye;
    }

    public void setGerenshiye(BigDecimal gerenshiye) {
        this.gerenshiye = gerenshiye;
    }
    public BigDecimal getGerengongjijin() {
        return gerengongjijin;
    }

    public void setGerengongjijin(BigDecimal gerengongjijin) {
        this.gerengongjijin = gerengongjijin;
    }
    public BigDecimal getGeshui() {
        return geshui;
    }

    public void setGeshui(BigDecimal geshui) {
        this.geshui = geshui;
    }
    public BigDecimal getYingfamianshui() {
        return yingfamianshui;
    }

    public void setYingfamianshui(BigDecimal yingfamianshui) {
        this.yingfamianshui = yingfamianshui;
    }
    public BigDecimal getYingfamianshuicw() {
        return yingfamianshuicw;
    }

    public void setYingfamianshuicw(BigDecimal yingfamianshuicw) {
        this.yingfamianshuicw = yingfamianshuicw;
    }
    public BigDecimal getActual() {
        return actual;
    }

    public void setActual(BigDecimal actual) {
        this.actual = actual;
    }
    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    public String getBankAccount() {
        return bankAccount;
    }

    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }
    public String getBankAddress() {
        return bankAddress;
    }

    public void setBankAddress(String bankAddress) {
        this.bankAddress = bankAddress;
    }
    public String getAcSetCode() {
        return acSetCode;
    }

    public void setAcSetCode(String acSetCode) {
        this.acSetCode = acSetCode;
    }
    public String getAcSet() {
        return acSet;
    }

    public void setAcSet(String acSet) {
        this.acSet = acSet;
    }
    
}
